"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@epandco/unthink-foundation/lib/core");
/**
 * This function wraps Express middleware to make it compatible UnthinkMiddleware.
 */
function expressMiddleware(handler) {
    const expressHandler = handler;
    expressHandler.__expressMiddleware = 'EXPRESS_MIDDLEWARE';
    expressHandler.__middlewareType = core_1.MiddlewareType.RAW;
    return expressHandler;
}
exports.expressMiddleware = expressMiddleware;
/**
 * @deprecated This function has been deprecated since version 2 and will be removed in next major version.
 *             Please use the unthinkResource function as a replacement found in the unthink-foundation package.
 */
function expressResource(resourceDefinition) {
    var _a, _b, _c;
    /**
     * This explicit cast to the target type is intentional and done to simplify the conversation.
     *
     * The middleware is the only difference between them and by using Object.assign and the cast the new object is
     * pretty much assigned just need to wrap the raw middleware via expressMiddleware and the type will be complete.
     */
    const resource = Object.assign({}, resourceDefinition);
    resource.middleware = (_a = resourceDefinition.middleware) === null || _a === void 0 ? void 0 : _a.map(expressMiddleware);
    for (const route of resource.routes) {
        route.middleware = (_b = route.middleware) === null || _b === void 0 ? void 0 : _b.map(
        // This looks odd but due to the cast above the middleware looks like the correct type, UnthinkMiddleware, but
        // in reality is still RequestHandler and needs to be converted. So have to cast to unknown and then back to the
        // original RequestHandler type.
        p => expressMiddleware(p));
        for (const method in route.methods) {
            const resourceHandlerObj = route.methods[method];
            if (!resourceHandlerObj) {
                throw new Error('Handler must be defined.');
            }
            if ('handler' in resourceHandlerObj) {
                // This looks odd but due to the cast above the middleware looks like the correct type, UnthinkMiddleware, but
                // in reality is still RequestHandler and needs to be converted. So have to cast to unknown and then back to the
                // original RequestHandler type.
                resourceHandlerObj.middleware = (_c = resourceHandlerObj.middleware) === null || _c === void 0 ? void 0 : _c.map(p => expressMiddleware(p));
            }
        }
    }
    return resource;
}
exports.expressResource = expressResource;
//# sourceMappingURL=express-resource.js.map